@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2005 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2006 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,17 +22,29 @@
 #ifndef ___COMMON_H
 #define ___COMMON_H
 
-#ifndef VDRVERSNUM
+#ifndef APIVERSNUM
 #include <vdr/config.h>
 #endif
 #include "config.h"
 
-#if VDRVERSNUM >= 10318
+#if APIVERSNUM >= 10313
+#define SLEEP(x) cCondWait::SleepMs(x)
+#else
+#define SLEEP(x) usleep((x)*1000)
+#endif
+
+#if APIVERSNUM >= 10318
 #include <vdr/tools.h>
 static cTimeMs __time;
 #define time_ms() ((int)__time.Elapsed())
 #endif
 
+#if APIVERSNUM >= 10338
+#define BUTTON "Button$"
+#else
+#define BUTTON
+#endif
+
 #if !defined(NO_DEBUG) && defined(DEBUG)
 #define d(x) { (x); }
 #else
