@@ -200,6 +200,33 @@ eDecodeStatus cMP3Decoder::DecodeError(bool hdr)
     return dsError;
     }
   else { 
+    if(stream->error==MAD_ERROR_LOSTSYNC) { // check for ID3 tags
+#ifdef DEBUG
+      char buf[10];
+      int buf2[3];
+      memcpy(buf,stream->this_frame,8); buf[8]=0;
+      memcpy(buf2,stream->this_frame,8);
+      printf("mad: lost sync %08x %08x %s\n",buf2[0],buf2[1],buf);
+#endif
+      id3_length_t count=stream->bufend-stream->this_frame;
+      id3_length_t tagsize=id3_tag_query(stream->this_frame,count);
+      if(tagsize>0) {
+        d(printf("mad: skipping over ID3 tag\n"))
+        if(count>tagsize) count=tagsize;
+        mad_stream_skip(stream,count);
+        while(count<tagsize) {
+          unsigned char *sdata;
+          unsigned long slen;
+          if(!str->Stream(sdata,slen)) return dsError;
+          if(slen<=0) return dsEof;
+          unsigned long len=min(tagsize-count,slen);
+          count+=len;
+          sdata+=len; slen-=len;
+          if(slen>0) mad_stream_buffer(stream,sdata,slen);
+          }
+        return dsOK;
+        }
+      }
     errcount+=hdr?1:100;
     d(printf("mad: decode %serror, frame=%d count=%d: %s\n",hdr?"hdr ":"",framenum,errcount,mad_stream_errorstr(stream)))
     }
@@ -331,6 +358,7 @@ bool cScanID3::DoScan(bool KeepOpen)
   mad_timer_t duration=mad_timer_zero;
   unsigned int bitrate=0, minrate=~0, maxrate=0;
   int xframes=0;
+  unsigned int id3_vers=0;
   bool is_vbr=false, has_id3=false;
 
   keepOpen=KeepOpen;
@@ -343,7 +371,7 @@ bool cScanID3::DoScan(bool KeepOpen)
     Set(dat); dat->Unlock();
     if(!DecoderID) {
       DecoderID=DEC_MP3;
-      InfoCache.Cache(this,str,true);
+      InfoCache.Cache(this,str);
       }
     return Abort(true);
     }
@@ -358,9 +386,9 @@ bool cScanID3::DoScan(bool KeepOpen)
     if(str->Stream(data,len)) {
       struct id3_tag *tag=id3_tag_parse(data,len);
       if(tag) {
-        d(printf("mad: initialy found id3 tag at EOF\n"))
-        has_id3=true;
+        d(printf("id3-scan: initialy found ID3 V1 tag at EOF\n"))
         ParseID3(tag);
+        has_id3=true; id3_vers=tag->version;
         id3_tag_delete(tag);
         }
       }
@@ -398,28 +426,31 @@ bool cScanID3::DoScan(bool KeepOpen)
         if(s<0) res=false;
         break;
         }
-      else if(stream.error==MAD_ERROR_LOSTSYNC && !has_id3) { // check for ID3 tags
+      else if(stream.error==MAD_ERROR_LOSTSYNC) { // check for ID3 tags
 #ifdef DEBUG
         char buf[10];
         int buf2[3];
         memcpy(buf,stream.this_frame,8); buf[8]=0;
         memcpy(buf2,stream.this_frame,8);
-        printf("mad: id3-scan, lost sync %08x %08x %s\n",buf2[0],buf2[1],buf);
+        printf("id3-scan: lost sync %08x %08x %s\n",buf2[0],buf2[1],buf);
 #endif
         id3_length_t tagsize=id3_tag_query(stream.this_frame,stream.bufend-stream.this_frame);
         if(tagsize>0) {
 	  struct id3_tag *tag=GetID3(&stream,tagsize);
 	  if(tag) {
-            d(printf("mad: found id3 tag\n"))
-            has_id3=true;
-            ParseID3(tag);
+            unsigned int vers=id3_tag_version(tag);
+            d(printf("id3-scan: found ID3 %s tag (%d.%d)\n",vers==0x100?"V1":"V2",ID3_TAG_VERSION_MAJOR(vers),ID3_TAG_VERSION_MINOR(vers)))
+            if(!has_id3 || vers>id3_vers) {
+              ParseID3(tag);
+              has_id3=true; id3_vers=vers;
+              }
 	    id3_tag_delete(tag);
 	    }
           }
         continue;
         }
       else {
-        d(printf("mad: id3-scan, decode header error (frame %d): %s\n",Frames,mad_stream_errorstr(&stream)))
+        d(printf("id3-scan: decode header error (frame %d): %s\n",Frames,mad_stream_errorstr(&stream)))
         errcount++;
         if(errcount<MAX_FRAME_ERR*100 && MAD_RECOVERABLE(stream.error)) continue;
         res=false; break;
@@ -495,7 +526,7 @@ bool cScanID3::DoScan(bool KeepOpen)
 // This function was adapted from player.c, from the 
 // libmad distribution
 
-struct id3_tag *cScanID3::GetID3(struct mad_stream *stream, id3_length_t tagsize)
+struct id3_tag *cScanID3::GetID3(struct mad_stream *stream, id3_length_t tagsize) const
 {
   struct id3_tag *tag=0;
   const id3_byte_t *data;
@@ -540,6 +571,7 @@ struct id3_tag *cScanID3::GetID3(struct mad_stream *stream, id3_length_t tagsize
 
 void cScanID3::ParseID3(const struct id3_tag *tag)
 {
+  d(printf("id3-scan: parsing ID3 tag\n"))
   ParseStr(tag,ID3_FRAME_TITLE,Title);
   ParseStr(tag,ID3_FRAME_ARTIST,Artist);
   ParseStr(tag,ID3_FRAME_ALBUM,Album);
@@ -551,6 +583,21 @@ void cScanID3::ParseID3(const struct id3_tag *tag)
   //ParseStr(tag,ID3_FRAME_GENRE,Genre);
 }
 
+/*
+void cScanID3::ParsePic(const struct id3_tag *tag, const char *id, char * &name)
+{
+  const struct id3_frame *frame=id3_tag_findframe(tag,id,0);
+  if(frame) {
+    id3_length_t len;
+    const id3_byte_t *data=id3_field_getbinarydata(&frame->fields[1],&len);
+    if(data && len>0) {
+      static const char salt[] = { "$1$id3__pic$" };
+      
+      }
+    }
+}
+*/
+
 // This function was adapted from player.c, from the 
 // libmad distribution 
 
@@ -583,7 +630,7 @@ void cScanID3::ParseStr(const struct id3_tag *tag, const char *id, char * &data)
 // #define XING_TOC    0x0004
 // #define XING_SCALE  0x0008
 
-int cScanID3::ParseXing(struct mad_bitptr *ptr, unsigned int bitlen)
+int cScanID3::ParseXing(struct mad_bitptr *ptr, unsigned int bitlen) const
 {
   if(bitlen>=64 && mad_bit_read(ptr,32)==XING_MAGIC) {
     int flags=mad_bit_read(ptr, 32);
