@@ -456,7 +456,8 @@ bool cCacheData::Load(FILE *f)
 
 cInfoCache::cInfoCache(void)
 {
-  lasttime=lastpurge=0; modified=false;
+  lasttime=0; modified=false;
+  lastpurge=time(0)-(50*60);
 }
 
 void cInfoCache::Cache(cSongInfo *info, cFileInfo *file)
@@ -527,25 +528,38 @@ cCacheData *cInfoCache::FirstEntry(int hash)
   return lists[hash%CACHELINES].First();
 }
 
-void cInfoCache::Purge(void)
+bool cInfoCache::Purge(void)
 {
   time_t now=time(0);
-  struct tm tm_r;
-  struct tm *ptm = localtime_r(&now, &tm_r);
-  if(now-lastpurge>3600 && ptm->tm_hour==5) {
+  if(now-lastpurge>(60*60)) {
     isyslog("cleaning up id3 cache");
-    lock.Lock();
-    for(int i=0 ; i<CACHELINES ; i++) {
-      cCacheData *dat=FirstEntry(i);
-      while(dat) {
-        cCacheData *ndat=(cCacheData *)dat->Next();
-        if(dat->Purge()) DelEntry(dat);
-        dat=ndat;
-        }
-      }
-    lock.Unlock();
+    Start();
     lastpurge=now;
     }
+  return Active();
+}
+
+void cInfoCache::Action(void)
+{
+  d(printf("cache: id3 cache purge thread started (pid=%d)\n",getpid()))
+  nice(3);
+  lock.Lock();
+  for(int i=0,n=0 ; i<CACHELINES && Running(); i++) {
+    cCacheData *dat=FirstEntry(i);
+    while(dat && Running()) {
+      cCacheData *ndat=(cCacheData *)dat->Next();
+      if(dat->Purge()) DelEntry(dat);
+      dat=ndat;
+
+      if(++n>30) {
+        lastmod=false; n=0;
+        lock.Unlock(); lock.Lock();    // give concurrent thread an access chance
+        if(lastmod) dat=FirstEntry(i); // restart line, if cache changed meanwhile
+        }
+      }
+    }
+  lock.Unlock();
+  d(printf("cache: id3 cache purge thread ended (pid=%d)\n",getpid()))
 }
 
 char *cInfoCache::CacheFile(void)
@@ -555,8 +569,7 @@ char *cInfoCache::CacheFile(void)
 
 void cInfoCache::Save(bool force)
 {
-  Purge();
-  if(modified && (force || time(0)>lasttime)) {
+  if(!Purge() && modified && (force || time(0)>lasttime)) {
     char *name=CacheFile();
     cSafeFile f(name);
     free(name);
