@@ -132,23 +132,25 @@ public:
 
 #define CACHELINES 32
 
-class cInfoCache {
+class cInfoCache : public cThread {
 private:
   cMutex lock;
   cList<cCacheData> lists[CACHELINES];
   time_t lasttime, lastpurge;
-  bool modified;
+  bool modified, lastmod;
   //
   char *CacheFile(void);
   void AddEntry(cCacheData *dat);
   void DelEntry(cCacheData *dat);
   cCacheData *FirstEntry(int hash);
-  void Modified(void) { modified=true; }
+  void Modified(void) { modified=lastmod=true; }
+protected:
+  virtual void Action(void);
 public:
   cInfoCache(void);
   void Save(bool force=false);
   void Load(void);
-  void Purge(void);
+  bool Purge(void);
   void Cache(cSongInfo *info, cFileInfo *file);
   cCacheData *Search(cFileInfo *file);
   };
