@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2005 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2006 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -54,7 +54,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Anterior",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -74,7 +74,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Escollir",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -94,7 +94,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Error al llegir una carpeta!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  !",
 #endif
   },
@@ -114,7 +114,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Orgen",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -134,7 +134,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Mount",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -154,8 +154,28 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Unmount",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
+#endif
+  },
+  { "Eject",
+    "Auswerfen",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "Avaa",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+#if APIVERSNUM >= 10302
+    "", // TODO
 #endif
   },
   { "Selected source is not mounted!",
@@ -174,7 +194,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "l'Origen sel.leccionat no est muntat!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   !",
 #endif
   },
@@ -194,7 +214,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "mount correcte",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -214,7 +234,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "No he pogut muntar!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  !",
 #endif
   },
@@ -234,7 +254,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "unmount amb xit",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -254,7 +274,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "No puc desmontar!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  !",
 #endif
   },
@@ -274,7 +294,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "No puc expulsar!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  !",
 #endif
   },
@@ -294,7 +314,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   ",
 #endif
   },
@@ -317,7 +337,7 @@ const tI18nPhrase Phrases[] = {
     "MP3",
     "MP3",
     "MP3",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " MP3",
 #endif
   },
@@ -337,7 +357,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -357,7 +377,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Explorar",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -377,7 +397,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Orgen MP3",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " MP3",
 #endif
   },
@@ -397,7 +417,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Reanomenar",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -417,7 +437,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Afegir",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -437,7 +457,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Esborrar",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -457,7 +477,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Escoltar-ho tot",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -477,7 +497,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Afegir-ho tot",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -497,7 +517,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Carpeta buida!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " !",
 #endif
   },
@@ -517,7 +537,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Afegir recursivament?",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ?",
 #endif
   },
@@ -537,7 +557,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Esborrar la entrada?",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ?",
 #endif
   },
@@ -557,7 +577,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Editor de llistes de reproducci",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ",
 #endif
   },
@@ -577,7 +597,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Navegar per les carpetes",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -597,7 +617,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Esborrar la Llista?",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -617,7 +637,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "N'esteu segur?",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ?",
 #endif
   },
@@ -637,7 +657,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "sense nom",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -657,7 +677,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "desconegut",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -677,7 +697,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Error al llegir les llistes!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   !",
 #endif
   },
@@ -697,7 +717,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Error al esborrar una llista!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   !",
 #endif
   },
@@ -717,7 +737,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Error al crear una llista!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   !",
 #endif
   },
@@ -737,7 +757,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "No puc editar una llista del WinAmp!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   WinAmp!",
 #endif
   },
@@ -757,7 +777,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Error al reanomenar la llista!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  !",
 #endif
   },
@@ -777,7 +797,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Carregant la llista de reproducci...",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ...",
 #endif
   },
@@ -797,7 +817,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Error al carregar la llista de reproducci!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   !",
 #endif
   },
@@ -817,7 +837,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Llegint les llistes de reproducci...",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ...",
 #endif
   },
@@ -837,7 +857,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Revisant les carpetes..",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ...",
 #endif
   },
@@ -857,7 +877,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Construnt la llista de reproducci...",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ...",
 #endif
   },
@@ -877,7 +897,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Error al consstruir la llista de reproducci!",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   !",
 #endif
   },
@@ -897,7 +917,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Consultant CDDB...",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "    CDDB...",
 #endif
   },
@@ -917,7 +937,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Connectant al servidor...",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   ...",
 #endif
   },
@@ -937,7 +957,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Reanomenar la llista de repr.",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ",
 #endif
   },
@@ -957,7 +977,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Nom anterior:",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " :",
 #endif
   },
@@ -977,7 +997,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Nou nom", 
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " :",
 #endif
   },
@@ -997,7 +1017,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", 
     "Nom dels arxius",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1017,7 +1037,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Nom ID3",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "ID3-",
 #endif
   },
@@ -1037,7 +1057,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Informaci ID3",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "ID3-",
 #endif
   },
@@ -1057,7 +1077,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "ID3 info",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ID3",
 #endif
   },
@@ -1077,7 +1097,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Nom de l'arxiu",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1097,7 +1117,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Durada",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1117,7 +1137,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Ttol",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1137,7 +1157,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Intrpret",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1157,7 +1177,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "lbum",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1177,7 +1197,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Any",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1197,7 +1217,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Freqncia",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1217,7 +1237,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Bitrate",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1237,7 +1257,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Mode de repetici inicial",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   ",
 #endif
   },
@@ -1257,8 +1277,68 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Lectura aleatria inicial",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " .   ",
+#endif
+  },
+  { "Setup.MP3$Title/Artist order",
+    "Title/Artist Reihenfolge",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "",
+    "", // TODO
+    "Nyt kappale ja esittj",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+#if APIVERSNUM >= 10302
+    "",
+#endif
+  },
+  { "Normal",
+    "Normal",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "",
+    "", // TODO
+    "normaalisti",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+#if APIVERSNUM >= 10302
+    "",
+#endif
+  },
+  { "Reversed",
+    "Umgedreht",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "",
+    "", // TODO
+    "knnettyn",
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+    "", // TODO
+#if APIVERSNUM >= 10302
+    "",
 #endif
   },
   { "Setup.MP3$Audio output mode",
@@ -1277,7 +1357,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ",
 #endif
   },
@@ -1297,7 +1377,7 @@ const tI18nPhrase Phrases[] = {
     "OSS",
     "OSS",
     "OSS",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "OSS",
 #endif
   },
@@ -1317,7 +1397,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Mode d'audio",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ",
 #endif
   },
@@ -1337,7 +1417,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Arrodonir",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1357,7 +1437,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Compactar",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1377,7 +1457,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1397,7 +1477,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ID3",
 #endif
   },
@@ -1417,7 +1497,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "ID3  ",
 #endif
   },
@@ -1437,7 +1517,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Mode de visualitzaci del editor",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ",
 #endif
   },
@@ -1457,7 +1537,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Mode de visualitzaci",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1477,7 +1557,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Execuci de fons",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1497,7 +1577,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "CDDB per al Audio-CD",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "CDDB  -CD",
 #endif
   },
@@ -1517,7 +1597,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "desactivat",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1537,7 +1617,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "solsament local",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " .",
 #endif
   },
@@ -1557,7 +1637,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "local i remot",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     ".  .",
 #endif
   },
@@ -1577,7 +1657,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Noms mode 48kHz",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " 48 ڳ",
 #endif
   },
@@ -1597,7 +1677,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Utillitzar proxy HTTP",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " HTTP ",
 #endif
   },
@@ -1617,7 +1697,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Nom del proxy HTTP",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " HTTP ",
 #endif
   },
@@ -1637,7 +1717,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Port del proxy HTTP",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " HTTP ",
 #endif
   },
@@ -1657,7 +1737,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Servidor CDDB",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " CDDB",
 #endif
   },
@@ -1677,7 +1757,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Port CDDB",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " CDDB",
 #endif
   },
@@ -1697,7 +1777,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Negre",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1717,7 +1797,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Imatge",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1737,7 +1817,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1757,7 +1837,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Men Principal",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ",
 #endif
   },
@@ -1777,7 +1857,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Llista a reprodur",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1797,7 +1877,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Navegador",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1817,7 +1897,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Nivell de normalitzaci",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1837,7 +1917,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Limitador del nivell",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  ",
 #endif
   },
@@ -1857,7 +1937,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "    ",
 #endif
   },
@@ -1877,7 +1957,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "   ",
 #endif
   },
@@ -1897,7 +1977,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1917,7 +1997,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1937,7 +2017,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -1960,7 +2040,7 @@ const tI18nPhrase Phrases[] = {
     "MPlayer",
     "MPlayer",
     "MPlayer",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -1980,7 +2060,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "", // TODO
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -2000,7 +2080,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Navegador del MPlayer",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  MPlayer",
 #endif
   },
@@ -2020,7 +2100,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Orgen del MPlayer",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "  MPlayer",
 #endif
   },
@@ -2040,7 +2120,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Mode de control",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     " ",
 #endif
   },
@@ -2060,7 +2140,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Tradicional",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -2080,7 +2160,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "Esclau",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -2100,7 +2180,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -2120,7 +2200,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -2140,7 +2220,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -2160,7 +2240,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -2180,7 +2260,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -2200,7 +2280,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
@@ -2220,7 +2300,7 @@ const tI18nPhrase Phrases[] = {
     "", // TODO
     "", // TODO
     "",
-#if VDRVERSNUM >= 10302
+#if APIVERSNUM >= 10302
     "",
 #endif
   },
