@@ -2,8 +2,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#undef VDRVERSNUM
-#define VDRVERSNUM 10307 // to keep common.h happy
+#undef APIVERSNUM
+#define APIVERSNUM 10307 // to keep common.h happy
 
 #include "i18n.h"
 #include "i18n.c"
