@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2005 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2006 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,7 +29,7 @@
 #include <vdr/menuitems.h>
 #include <vdr/status.h>
 #include <vdr/plugin.h>
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
 #include <vdr/interface.h>
 #include <vdr/skins.h>
 #endif
@@ -44,11 +44,13 @@
 #include "decoder.h"
 #include "i18n.h"
 #include "version.h"
+#include "service.h"
 
 #ifdef DEBUG
 #include <mad.h>
 #endif
 
+const char *sourcesSub=0;
 cFileSources MP3Sources;
 
 // --- cMenuSetupMP3 --------------------------------------------------------
@@ -83,7 +85,7 @@ cMenuSetupMP3::cMenuSetupMP3(void)
   Add(new cMenuEditStraItem(tr("Setup.MP3$Audio output mode"),     &amode,numModes,aout));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Audio mode"),            &data.AudioMode, tr("Round"), tr("Dither")));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Use 48kHz mode only"),   &data.Only48kHz));
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   disp[0]=tr("classic");
   disp[1]=tr("via skin");
   Add(new cMenuEditStraItem(tr("Setup.MP3$Replay display"),        &data.ReplayDisplay, 2, disp));
@@ -103,6 +105,7 @@ cMenuSetupMP3::cMenuSetupMP3(void)
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Editor display mode"),   &data.EditorMode, tr("Filenames"), tr("ID3 names")));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Mainmenu mode"),         &data.MenuMode, tr("Playlists"), tr("Browser")));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Keep selection menu"),   &data.KeepSelect));
+  Add(new cMenuEditBoolItem(tr("Setup.MP3$Title/Artist order"),    &data.TitleArtistOrder, tr("Normal"), tr("Reversed")));
   Add(new cMenuEditBoolItem(tr("Hide mainmenu entry"),             &data.HideMainMenu));
   Add(new cMenuEditIntItem( tr("Setup.MP3$Normalizer level"),      &data.TargetLevel, 0, MAX_TARGET_LEVEL));
   Add(new cMenuEditIntItem( tr("Setup.MP3$Limiter level"),         &data.LimiterLevel, MIN_LIMITER_LEVEL, 100));
@@ -141,11 +144,12 @@ void cMenuSetupMP3::Store(void)
   SetupStore("CddbHost",         MP3Setup.CddbHost       );
   SetupStore("CddbPort",         MP3Setup.CddbPort       );
   SetupStore("AbortAtEOL",       MP3Setup.AbortAtEOL     );
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   SetupStore("ReplayDisplay",    MP3Setup.ReplayDisplay  );
 #endif
   SetupStore("HideMainMenu",     MP3Setup.HideMainMenu   );
   SetupStore("KeepSelect",       MP3Setup.KeepSelect     );
+  SetupStore("TitleArtistOrder", MP3Setup.TitleArtistOrder);
 }
 
 // --- cAsyncStatus ------------------------------------------------------------
@@ -184,9 +188,24 @@ void cAsyncStatus::Finish(void)
   Unlock();
 }
 
+// --- --------------------------------------------------------------------
+
+static const char *TitleArtist(const char *title, const char *artist)
+{
+  static char buf[256]; // clearly not multi-thread save!
+  char *fmt;
+  if(artist && artist[0]) {
+    if(MP3Setup.TitleArtistOrder) fmt="%2$s - %1$s";
+    else  fmt="%s - %s";
+    }
+  else fmt="%s";
+  snprintf(buf,sizeof(buf),fmt,title,artist);
+  return buf;
+}
+
 // --- cMP3Control --------------------------------------------------------
 
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
 #define clrBackground clrGray50
 #define eDvbColor int
 #define MAXROWS 120
@@ -198,7 +217,7 @@ void cAsyncStatus::Finish(void)
 
 class cMP3Control : public cControl {
 private:
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   cOsd *osd;
   const cFont *font;
   cSkinDisplayReplay *disp;
@@ -253,13 +272,13 @@ cMP3Control::cMP3Control(void)
   lastkeytime=number=0;
   lastMode=0;
   framesPerSecond=SecondsToFrames(1);
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   osd=0; disp=0;
   font=cFont::GetFont(fontOsd);
 #else
   statusInterfaceOpen=false;
 #endif
-#if VDRVERSNUM >= 10338
+#if APIVERSNUM >= 10338
   cStatus::MsgReplaying(this,"MP3",0,true);
 #else
   cStatus::MsgReplaying(this,"MP3");
@@ -275,7 +294,7 @@ cMP3Control::~cMP3Control()
 
 void cMP3Control::Stop(void)
 {
-#if VDRVERSNUM >= 10338
+#if APIVERSNUM >= 10338
   cStatus::MsgReplaying(this,0,0,false);
 #else
   cStatus::MsgReplaying(this,0);
@@ -317,7 +336,7 @@ void cMP3Control::Hide(void)
 {
   HideStatus();
   if(visible) {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
     delete osd; osd=0;
     delete disp; disp=0;
 #else
@@ -332,7 +351,7 @@ void cMP3Control::ShowStatus(bool force)
   if((asyncStatus.Changed() || (force && !statusActive)) && !jumpactive) {
     const char *text=asyncStatus.Begin();
     if(text) {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
       if(MP3Setup.ReplayDisplay || !osd) {
         if(statusActive) Skins.Message(mtStatus,0);
         Skins.Message(mtStatus,text);
@@ -361,7 +380,7 @@ void cMP3Control::ShowStatus(bool force)
 void cMP3Control::HideStatus(void)
 {
   if(statusActive) {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
     if(MP3Setup.ReplayDisplay || !osd)
       Skins.Message(mtStatus,0);
     else {
@@ -387,7 +406,7 @@ void cMP3Control::HideStatus(void)
 
 void cMP3Control::Write(int x, int y, int w, const char *text, eDvbColor fg, eDvbColor bg)
 {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   if(osd) {
     //d(printf("write x=%d y=%d w=%d ->",x,y,w))
     x*=fw; if(x<0) x+=bw;
@@ -403,7 +422,7 @@ void cMP3Control::Write(int x, int y, int w, const char *text, eDvbColor fg, eDv
 
 void cMP3Control::Fill(int x, int y, int w, int h, eDvbColor fg)
 {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   if(osd) {
     //d(printf("fill x=%d y=%d w=%d h=%d ->",x,y,w,h))
     x*=fw; if(x<0) x+=bw;
@@ -418,7 +437,7 @@ void cMP3Control::Fill(int x, int y, int w, int h, eDvbColor fg)
 
 void cMP3Control::Flush(void)
 {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   if(MP3Setup.ReplayDisplay) Skins.Flush();
   else if(osd) osd->Flush();
 #else
@@ -433,7 +452,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
   if(player->GetIndex(index,total) && total>=0) {
     if(!visible && open) {
       HideStatus();
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
       if(MP3Setup.ReplayDisplay) {
         disp=Skins.Current()->DisplayReplay(false);
         if(!disp) return;
@@ -496,9 +515,9 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
 
     if(valid) { // send progress to status monitor
       if(changed || mode->Loop!=lastMode->Loop || mode->Shuffle!=lastMode->Shuffle) {
-        snprintf(buf,sizeof(buf),mode->Artist[0]?"[%c%c] (%d/%d) %s - %s":"[%c%c] (%d/%d) %s",
-                  mode->Loop?'L':'.',mode->Shuffle?'S':'.',mode->Num,mode->MaxNum,mode->Title,mode->Artist);
-#if VDRVERSNUM >= 10338
+        snprintf(buf,sizeof(buf),"[%c%c] (%d/%d) %s",
+                  mode->Loop?'L':'.',mode->Shuffle?'S':'.',mode->Num,mode->MaxNum,TitleArtist(mode->Title,mode->Artist));
+#if APIVERSNUM >= 10338
         cStatus::MsgReplaying(this,buf,mode->Filename[0]?mode->Filename:0,true);
 #else
         cStatus::MsgReplaying(this,buf);
@@ -509,7 +528,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
     if(visible) { // refresh the OSD progress display
       bool flush=false;
 
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
       if(MP3Setup.ReplayDisplay) {
         if(!statusActive) {
           if(total>0) disp->SetProgress(index,total);
@@ -544,7 +563,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
         index/=framesPerSecond; total/=framesPerSecond;
         if(index!=lastIndex || total!=lastTotal) {
           if(total>0) {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
             cProgressBar ProgressBar(bw-(CTAB+CTAB2)*fw,fh,index,total);
             osd->DrawBitmap(CTAB*fw,bh-fh,ProgressBar);
 #else
@@ -556,7 +575,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
           Write(0,-1,11,buf);
           flush=true;
           }
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
         }
 #endif
 
@@ -580,7 +599,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
 	      flip=0;
 	      // fall through
 	    case 0:
-	      snprintf(buf,sizeof(buf),mode->Artist[0]?"%s - %s":"%s",mode->Title,mode->Artist);
+	      snprintf(buf,sizeof(buf),"%s",TitleArtist(mode->Title,mode->Artist));
 	      flipint=6;
 	      break;
 	    case 1:
@@ -599,7 +618,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
 	      break;
 	    }
           if(buf[0]) {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
             if(MP3Setup.ReplayDisplay) {
               char buf2[256];
               snprintf(buf2,sizeof(buf2),"[%c%c] (%d/%d) %s",
@@ -614,7 +633,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
                 flush=true;
                 }
               else { d(printf("mp3-ctrl: display info skip due to status active\n")) }
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
               }
 #endif
             }
@@ -631,7 +650,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
           for(int i=0 ; i<rows && i<MAXROWS && num<=mode->MaxNum ; i++,num++) {
             cMP3PlayInfo pi;
             mgr->Info(num,&pi); if(!pi.Title[0]) break;
-            snprintf(buf,sizeof(buf),pi.Artist[0]?"%d.\t%s - %s":"%d.\t%s",num,pi.Title,pi.Artist);
+            snprintf(buf,sizeof(buf),"%d.\t%s",num,TitleArtist(pi.Title,pi.Artist));
             eDvbColor fg=clrWhite, bg=clrBackground;
             int hash=MakeHash(buf);
             if(num==mode->Num) { fg=clrBlack; bg=clrCyan; hash=(hash^77) + 23; }
@@ -672,14 +691,14 @@ void cMP3Control::JumpDisplay(void)
   const char *j=tr("Jump: "), u=jumpsecs?'s':'m';
   if(!jumpmm) sprintf(buf,"%s- %c",  j,u);
   else        sprintf(buf,"%s%d- %c",j,jumpmm,u);
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   if(MP3Setup.ReplayDisplay) {
     disp->SetJump(buf);
     }
   else {
 #endif
     DisplayInfo(buf);
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
     }
 #endif
 }
@@ -713,7 +732,7 @@ void cMP3Control::JumpProcess(eKeys Key)
 
   if(!jumpactive) {
     if(jumphide) Hide();
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
     else if(MP3Setup.ReplayDisplay) disp->SetJump(0);
 #endif
     }
@@ -736,7 +755,7 @@ eOSState cMP3Control::ProcessKey(eKeys Key)
 
   if(visible && timeoutShow && time(0)>timeoutShow) { Hide(); timeoutShow=0; }
   ShowProgress();
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   ShowStatus(Key==kNone && !Skins.IsOpen());
 #else
   ShowStatus(Key==kNone && !Interface->IsOpen());
@@ -807,7 +826,7 @@ eOSState cMP3Control::ProcessKey(eKeys Key)
       return osEnd;
     case kBack:
       Hide();
-#if VDRVERSNUM >= 10332
+#if APIVERSNUM >= 10332
       cRemote::CallPlugin(i18n_name);
       return osBack;
 #else
@@ -820,7 +839,7 @@ eOSState cMP3Control::ProcessKey(eKeys Key)
         if(!visible) { ShowTimed(); selecthide=true; }
         selecting=true; lastkeytime=time_ms();
         char buf[32];
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
         if(MP3Setup.ReplayDisplay) {
           snprintf(buf,sizeof(buf),"%s%d-/%d",tr("Jump: "),number,lastMode->MaxNum);
           disp->SetJump(buf);
@@ -829,7 +848,7 @@ eOSState cMP3Control::ProcessKey(eKeys Key)
 #endif
           snprintf(buf,sizeof(buf),"(%d-/%d)",number,lastMode->MaxNum);
           Write(0,-2,CTAB,buf);
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
           }
 #endif
         Flush();
@@ -843,7 +862,7 @@ eOSState cMP3Control::ProcessKey(eKeys Key)
         if(selecthide) timeoutShow=time(0)+SELECTHIDE_TIMEOUT;
         if(lastMode) lastMode->Hash=-1;
         number=0; selecting=selecthide=false;
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
         if(MP3Setup.ReplayDisplay) disp->SetJump(0);
 #endif
         }
@@ -929,7 +948,7 @@ cOsdItem *cMenuID3Info::Item(const char *name, const char *text)
   char *buf=0;
   asprintf(&buf,"%s:\t%s",name,text?text:"");
   cOsdItem *item = new cOsdItem(buf,osBack);
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   item->SetSelectable(false);
 #else
   item->SetColor(clrWhite, clrBackground);
@@ -968,9 +987,8 @@ public:
   };
 
 cMenuInstantBrowse::cMenuInstantBrowse(cFileSource *Source, const char *Selecttext, const char *Alltext)
-:cMenuBrowse(Source,true,true,tr("Directory browser"))
+:cMenuBrowse(Source,true,true,tr("Directory browser"),excl_br)
 {
-  excl=excl_br; // defined in data-mp3.c
   selecttext=Selecttext; alltext=Alltext;
   SetButtons();
 }
@@ -1040,7 +1058,7 @@ void cMenuPlayListItem::Set(void)
   cSongInfo *si=song->Info(false);
   if(showID3 && !si) si=song->Info();
   if(showID3 && si && si->Title)
-    asprintf(&buffer, "%d.\t%s%s%s",song->Index()+1,si->Title,si->Artist?" - ":"",si->Artist?si->Artist:"");
+    asprintf(&buffer, "%d.\t%s",song->Index()+1,TitleArtist(si->Title,si->Artist));
   else
     asprintf(&buffer, "%d.\t<%s>",song->Index()+1,song->Name());
   SetText(buffer,false);
@@ -1081,7 +1099,7 @@ cMenuPlayList::cMenuPlayList(cPlayList *Playlist)
 
 void cMenuPlayList::Buttons(void)
 {
-  SetHelp(tr("Add"), showid3?tr("Filenames"):tr("ID3 names"), tr("Remove"), tr("Mark"));
+  SetHelp(tr("Add"), showid3?tr("Filenames"):tr("ID3 names"), tr("Remove"), tr(BUTTON"Mark"));
 }
 
 void cMenuPlayList::Refresh(bool all)
@@ -1209,7 +1227,7 @@ cPlaylistRename::cPlaylistRename(const char *Oldname)
   char *buf=NULL;
   asprintf(&buf,"%s\t%s",tr("Old name:"),oldname);
   cOsdItem *old = new cOsdItem(buf,osContinue);
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   old->SetSelectable(false);
 #else
   old->SetColor(clrWhite, clrBackground);
@@ -1303,10 +1321,10 @@ eOSState cMenuMP3::SetButtons(int num)
 {
   switch(num) {
     case 1:
-      SetHelp(tr("Edit"), tr("Source"), tr("Browse"), ">>");
+      SetHelp(tr(BUTTON"Edit"), tr("Source"), tr("Browse"), ">>");
       break;
     case 2:
-      SetHelp("<<", tr("New"), tr("Delete"), tr("Rename"));
+      SetHelp("<<", tr(BUTTON"New"), tr(BUTTON"Delete"), tr("Rename"));
       break;
     }
   buttonnum=num; Display();
@@ -1445,7 +1463,7 @@ eOSState cMenuMP3::Instant(bool second)
 
   if(!second) {
     instanting=true;
-    return AddSubMenu(new cMenuInstantBrowse(MP3Sources.GetSource(),tr("Play"),tr("Play all")));
+    return AddSubMenu(new cMenuInstantBrowse(MP3Sources.GetSource(),tr(BUTTON"Play"),tr("Play all")));
     }
   instanting=false;
   cFileObj *item=cMenuInstantBrowse::GetSelected();
@@ -1504,6 +1522,10 @@ static const char *DESCRIPTION    = "A versatile audio player";
 static const char *MAINMENUENTRY  = "MP3";
 
 class cPluginMp3 : public cPlugin {
+private:
+#if APIVERSNUM >= 10330
+  bool ExternalPlay(const char *path, bool test);
+#endif
 public:
   cPluginMp3(void);
   virtual ~cPluginMp3();
@@ -1511,7 +1533,7 @@ public:
   virtual const char *Description(void) { return tr(DESCRIPTION); }
   virtual const char *CommandLineHelp(void);
   virtual bool ProcessArgs(int argc, char *argv[]);
-#if VDRVERSNUM >= 10131
+#if APIVERSNUM >= 10131
   virtual bool Initialize(void);
 #else
   virtual bool Start(void);
@@ -1521,6 +1543,13 @@ public:
   virtual cOsdObject *MainMenuAction(void);
   virtual cMenuSetupPage *SetupMenu(void);
   virtual bool SetupParse(const char *Name, const char *Value);
+#if APIVERSNUM >= 10330
+  virtual bool Service(const char *Id, void *Data);
+#if APIVERSNUM >= 10331
+  virtual const char **SVDRPHelpPages(void);
+  virtual cString SVDRPCommand(const char *Command, const char *Option, int &ReplyCode);
+#endif
+#endif
   };
 
 cPluginMp3::cPluginMp3(void)
@@ -1546,17 +1575,21 @@ const char *cPluginMp3::CommandLineHelp(void)
                      "  -n CMD,   --network=CMD  execute CMD before & after network access\n"
                      "                           (default: %s)\n"
                      "  -C DIR,   --cache=DIR    store ID3 cache file in DIR\n"
-                     "                           (default: video dir)\n"
+                     "                           (default: %s)\n"
                      "  -B DIR,   --cddb=DIR     search CDDB files in DIR\n"
                      "                           (default: %s)\n"
-                     "  -D DIR,   --dsp=DIR      device for OSS output\n"
+                     "  -D DEV,   --dsp=DEV      device for OSS output\n"
                      "                           (default: %s)\n"
                      "  -i CMD,   --iconv=CMD    use CMD to convert background images\n"
                      "                           (default: %s)\n"
                      "  -c DIR,   --icache=DIR   cache converted images in DIR\n"
+                     "                           (default: %s)\n"
+                     "  -S SUB,   --sources=SUB  search sources config in SUB subdirectory\n"
                      "                           (default: %s)\n",
                      
-                     mountscript,netscript?netscript:"none",
+                     mountscript,
+                     netscript ? netscript:"none",
+                     cachedir ? cachedir:"video dir",
 #ifdef HAVE_SNDFILE
                      cddbpath,
 #else
@@ -1567,7 +1600,9 @@ const char *cPluginMp3::CommandLineHelp(void)
 #else
                      "none",
 #endif
-                     imageconv,imagecache
+                     imageconv,
+                     imagecache,
+                     sourcesSub ? sourcesSub:"empty"
                      );
   return help_str;
 }
@@ -1582,17 +1617,19 @@ bool cPluginMp3::ProcessArgs(int argc, char *argv[])
       { "cache",    required_argument, NULL, 'C' },
       { "icache",   required_argument, NULL, 'c' },
       { "iconv",    required_argument, NULL, 'i' },
+      { "sources",  required_argument, NULL, 'S' },
       { NULL }
     };
 
   int c, option_index = 0;
-  while((c=getopt_long(argc,argv,"c:i:m:n:B:C:D:",long_options,&option_index))!=-1) {
+  while((c=getopt_long(argc,argv,"c:i:m:n:B:C:D:S:",long_options,&option_index))!=-1) {
     switch (c) {
       case 'i': imageconv=optarg; break;
       case 'c': imagecache=optarg; break;
       case 'm': mountscript=optarg; break;
       case 'n': netscript=optarg; break;
       case 'C': cachedir=optarg; break;
+      case 'S': sourcesSub=optarg; break;
       case 'B':
 #ifdef HAVE_SNDFILE
                 cddbpath=optarg; break;
@@ -1611,7 +1648,7 @@ bool cPluginMp3::ProcessArgs(int argc, char *argv[])
   return true;
 }
 
-#if VDRVERSNUM >= 10131
+#if APIVERSNUM >= 10131
 bool cPluginMp3::Initialize(void)
 #else
 bool cPluginMp3::Start(void)
@@ -1619,7 +1656,7 @@ bool cPluginMp3::Start(void)
 {
   if(!CheckVDRVersion(1,1,29,"mp3")) return false;
   i18n_name=Name();
-  MP3Sources.Load(AddDirectory(ConfigDirectory(),"mp3sources.conf"));
+  MP3Sources.Load(AddDirectory(ConfigDirectory(sourcesSub),"mp3sources.conf"));
   if(MP3Sources.Count()<1) {
      esyslog("ERROR: you should have defined at least one source in mp3sources.conf");
      fprintf(stderr,"No source(s) defined in mp3sources.conf\n");
@@ -1687,13 +1724,116 @@ bool cPluginMp3::SetupParse(const char *Name, const char *Value)
       }
 #endif
     }
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   else if (!strcasecmp(Name, "ReplayDisplay"))      MP3Setup.ReplayDisplay = atoi(Value);
 #endif
   else if (!strcasecmp(Name, "HideMainMenu"))       MP3Setup.HideMainMenu  = atoi(Value);
   else if (!strcasecmp(Name, "KeepSelect"))         MP3Setup.KeepSelect    = atoi(Value);
+  else if (!strcasecmp(Name, "TitleArtistOrder"))   MP3Setup.TitleArtistOrder = atoi(Value);
   else return false;
   return true;
 }
 
+#if APIVERSNUM >= 10330
+
+bool cPluginMp3::ExternalPlay(const char *path, bool test)
+{
+  char real[PATH_MAX+1];
+  if(realpath(path,real)) {
+    cFileSource *src=MP3Sources.FindSource(real);
+    if(src) {
+      cFileObj *item=new cFileObj(src,0,0,otFile);
+      if(item) {
+        item->SplitAndSet(real);
+        if(item->GuessType()) {
+          if(item->Exists()) {
+            cInstantPlayList *pl=new cInstantPlayList(item);
+            if(pl && pl->Load() && pl->Count()) {
+              if(!test) cMP3Control::SetPlayList(pl);
+              else delete pl;
+              delete item;
+              return true;
+              }
+            else dsyslog("MP3 service: error building playlist");
+            delete pl;
+            }
+          else dsyslog("MP3 service: cannot play '%s'",path);
+          }
+        else dsyslog("MP3 service: GuessType() failed for '%s'",path);
+        delete item;
+        }
+      }
+    else dsyslog("MP3 service: cannot find source for '%s', real '%s'",path,real);
+    }
+  else if(errno!=ENOENT && errno!=ENOTDIR)
+    esyslog("ERROR: realpath: %s: %s",path,strerror(errno));
+  return false;
+}
+
+bool cPluginMp3::Service(const char *Id, void *Data)
+{
+  if(!strcasecmp(Id,"MP3-Play-v1")) {
+    if(Data) {
+      struct MPlayerServiceData *msd=(struct MPlayerServiceData *)Data;
+      msd->result=ExternalPlay(msd->data.filename,false);
+      }
+    return true;
+    }
+  else if(!strcasecmp(Id,"MP3-Test-v1")) {
+    if(Data) {
+      struct MPlayerServiceData *msd=(struct MPlayerServiceData *)Data;
+      msd->result=ExternalPlay(msd->data.filename,true);
+      }
+    return true;
+    }
+  return false;
+}
+
+#if APIVERSNUM >= 10331
+
+const char **cPluginMp3::SVDRPHelpPages(void)
+{
+  static const char *HelpPages[] = {
+    "PLAY <filename>\n"
+    "    Triggers playback of file 'filename'.",
+    "TEST <filename>\n"
+    "    Tests is playback of file 'filename' is possible.",
+    "CURR\n"
+    "    Returns filename of song currently being replayed.",
+    NULL
+    };
+  return HelpPages;
+}
+
+cString cPluginMp3::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode)
+{
+  if(!strcasecmp(Command,"PLAY")) {
+    if(*Option) {
+      if(ExternalPlay(Option,false)) return "Playback triggered";
+      else { ReplyCode=550; return "Playback failed"; }
+      }
+    else { ReplyCode=501; return "Missing filename"; }
+    }
+  else if(!strcasecmp(Command,"TEST")) {
+    if(*Option) {
+      if(ExternalPlay(Option,true)) return "Playback possible";
+      else { ReplyCode=550; return "Playback not possible"; }
+      }
+    else { ReplyCode=501; return "Missing filename"; }
+    }
+  else if(!strcasecmp(Command,"CURR")) {
+    cControl *control=cControl::Control();
+    if(control && typeid(*control)==typeid(cMP3Control)) {
+      cMP3PlayInfo mode;
+      if(mgr->Info(-1,&mode)) return mode.Filename;
+      else return "<unknown>";
+      }
+    else { ReplyCode=550; return "No running playback"; }
+    }
+  return NULL;
+}
+
+#endif // 1.3.31
+#endif // 1.3.30
+
 VDRPLUGINCREATOR(cPluginMp3); // Don't touch this!
