@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2005 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2006 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,16 +34,16 @@
 #ifdef HAVE_BEAUTYPATCH
 #include <vdr/fontsym.h>
 #endif
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
 #include <vdr/skins.h>
 #endif
-#if VDRVERSNUM >= 10332
+#if APIVERSNUM >= 10332
 #include <vdr/remote.h>
 #endif
 
-#if VDRVERSNUM > 10307
+#if APIVERSNUM > 10307
 #include <vdr/menu.h>
-#elif VDRVERSNUM == 10307
+#elif APIVERSNUM == 10307
 class cMenuText : public cOsdMenu {
 private:
   char *text;
@@ -70,7 +70,9 @@ public:
 #include "data-src.h"
 #include "i18n.h"
 #include "version.h"
+#include "service.h"
 
+const char *sourcesSub=0;
 cFileSources MPlaySources;
 
 // --- cMenuSetupMPlayer --------------------------------------------------------
@@ -90,7 +92,7 @@ cMenuSetupMPlayer::cMenuSetupMPlayer(void)
   data=MPlayerSetup;
   SetSection(tr("MPlayer"));
   Add(new cMenuEditBoolItem(tr("Setup.MPlayer$Control mode"),  &data.SlaveMode, tr("Traditional"), tr("Slave")));
-#if VDRVERSNUM < 10307
+#if APIVERSNUM < 10307
   Add(new cMenuEditIntItem( tr("Setup.MPlayer$OSD position"),  &data.OsdPos, 0, 6));
 #endif
   res[0]=tr("disabled");
@@ -112,7 +114,7 @@ void cMenuSetupMPlayer::Store(void)
   SetupStore("ControlMode", MPlayerSetup.SlaveMode);
   SetupStore("HideMainMenu",MPlayerSetup.HideMainMenu);
   SetupStore("ResumeMode",  MPlayerSetup.ResumeMode);
-#if VDRVERSNUM < 10307
+#if APIVERSNUM < 10307
   SetupStore("OsdPos",      MPlayerSetup.OsdPos);
 #endif
   for(int i=0; i<10; i++) {
@@ -129,12 +131,13 @@ private:
   static cFileObj *file;
   static bool rewind;
   cMPlayerPlayer *player;
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   cSkinDisplayReplay *display;
 #endif
   bool visible, modeOnly, haveBeauty;
   time_t timeoutShow;
   int lastCurrent, lastTotal;
+  char *lastReplayMsg;
   //
   bool jumpactive, jumphide, jumpmode;
   int jumpval;
@@ -164,38 +167,40 @@ cMPlayerControl::cMPlayerControl(void)
 :cControl(player=new cMPlayerPlayer(file,rewind))
 {
   visible=modeOnly=jumpactive=haveBeauty=false;
-#if VDRVERSNUM >= 10307
+  lastReplayMsg=0;
+#if APIVERSNUM >= 10307
   display=0;
 #else
 #ifdef HAVE_BEAUTYPATCH
-#if VDRVERSNUM >= 10300
+#if APIVERSNUM >= 10300
   const cFont *sym=cFont::GetFont(fontSym);
   const cFont *osd=cFont::GetFont(fontOsd);
   const cFont::tCharData *symD=sym->CharData(32);
   const cFont::tCharData *osdD=osd->CharData(32);
-#else //VDRVERSNUM >= 10300
+#else //APIVERSNUM >= 10300
   cFont *sym=new cFont(fontSym);
   cFont *osd=new cFont(fontOsd);
   const cFont::tCharData *symD=sym->CharData(32);
   const cFont::tCharData *osdD=osd->CharData(32);
   delete sym;
   delete osd;
-#endif //VDRVERSNUM >= 10300
+#endif //APIVERSNUM >= 10300
   if(symD != osdD) haveBeauty=true;
   d(printf("mplayer: beauty patch %sdetected\n",haveBeauty?"":"NOT "))
 #endif //HAVE_BEAUTYPATCH
-#endif //VDRVERSNUM >= 10307
+#endif //APIVERSNUM >= 10307
   ShowTitle();
 }
 
 cMPlayerControl::~cMPlayerControl()
 {
   Stop();
-#if VDRVERSNUM >= 10338
+#if APIVERSNUM >= 10338
   cStatus::MsgReplaying(this,0,0,false);
 #else
   cStatus::MsgReplaying(this, NULL);
 #endif
+  free(lastReplayMsg);
 }
 
 void cMPlayerControl::SetFile(const cFileObj *File, bool Rewind)
@@ -222,7 +227,7 @@ void cMPlayerControl::ShowTimed(int Seconds)
 void cMPlayerControl::Hide(void)
 {
   if(visible) {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
     delete display; display=0;
 #else
     Interface->Close();
@@ -233,7 +238,7 @@ void cMPlayerControl::Hide(void)
 
 void cMPlayerControl::DisplayAtBottom(const char *s)
 {
-#if VDRVERSNUM < 10307
+#if APIVERSNUM < 10307
   const int p=modeOnly ? 0 : 2;
   if(s) {
     const int d=max(Width()-cOsd::WidthInCells(s),0) / 2;
@@ -247,21 +252,27 @@ void cMPlayerControl::DisplayAtBottom(const char *s)
 
 void cMPlayerControl::ShowTitle(void)
 {
-  const char *name=0;
+  const char *path=0;
   bool release=true;
-  if(player) name=player->GetCurrentName();
-  if(!name) {
-    name=file->Path();
+  if(player) path=player->GetCurrentName();
+  if(!path) {
+    path=file->FullPath();
     release=false;
     }
-  if(name) {
-#if VDRVERSNUM >= 10338
-    cStatus::MsgReplaying(this,name,0,true);
+  if(path) {
+    const char *name=rindex(path,'/');
+    if(name) name++; else name=path;
+    if(!lastReplayMsg || strcmp(lastReplayMsg,path)) {
+#if APIVERSNUM >= 10338
+      cStatus::MsgReplaying(this,name,path,true);
 #else
-    cStatus::MsgReplaying(this,name);
+      cStatus::MsgReplaying(this,path);
 #endif
+      free(lastReplayMsg);
+      lastReplayMsg=strdup(path);
+      }
     if(visible) {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
       if(display) display->SetTitle(name);
 #else
       int n=strlen(name);
@@ -275,7 +286,7 @@ void cMPlayerControl::ShowTitle(void)
 #endif
       }
     }
-  if(release) free((void *)name);
+  if(release) free((void *)path);
 }
 
 void cMPlayerControl::ShowProgress(void)
@@ -285,7 +296,7 @@ void cMPlayerControl::ShowProgress(void)
   if(GetIndex(Current,Total) && Total>0) {
     bool flush=false;
     if(!visible) {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
       display=Skins.Current()->DisplayReplay(false);
 #else
       Interface->Open(Setup.OSDwidth,-MPlayerSetup.OsdPos-3);
@@ -298,7 +309,7 @@ void cMPlayerControl::ShowProgress(void)
       }
 
     if(abs(Current-lastCurrent)>12) {
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
       if(Total>0) display->SetProgress(Current, Total);
       display->SetCurrent(IndexToHMSF(Current));
       display->SetTotal(IndexToHMSF(Total));
@@ -317,7 +328,7 @@ void cMPlayerControl::ShowProgress(void)
       lastCurrent=Current; lastTotal=Total;
       }
     if(flush) 
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
       Skins.Flush();
 #else
       Interface->Flush();
@@ -326,7 +337,7 @@ void cMPlayerControl::ShowProgress(void)
     }
 }
 
-#if VDRVERSNUM < 10307
+#if APIVERSNUM < 10307
 #ifdef HAVE_BEAUTYPATCH
 int forwSym[] = { FSYM_FORW,FSYM_FORW1,FSYM_FORW2,FSYM_FORW3 };
 int backSym[] = { FSYM_BACK,FSYM_BACK1,FSYM_BACK2,FSYM_BACK3 };
@@ -343,7 +354,7 @@ void cMPlayerControl::ShowMode(void)
 
        if(!visible) {
          if(NormalPlay) return;
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
          display = Skins.Current()->DisplayReplay(true);
 #else
          Interface->Open(0,-MPlayerSetup.OsdPos-1);
@@ -353,7 +364,7 @@ void cMPlayerControl::ShowMode(void)
 
        if(modeOnly && !timeoutShow && NormalPlay) timeoutShow=time(0)+SELECTHIDE_TIMEOUT;
 
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
        display->SetMode(Play, Forward, Speed);
 #else
        char buf[16];
@@ -386,7 +397,7 @@ void cMPlayerControl::ShowMode(void)
 #endif //HAVE_BEAUTYPATCH
        DisplayAtBottom(buf);
        Interface->SetFont(OldFont);
-#endif //VDRVERSNUM >= 10307
+#endif //APIVERSNUM >= 10307
        }
     }
 }
@@ -397,7 +408,7 @@ void cMPlayerControl::JumpDisplay(void)
   const char *j=tr("Jump: "), u=jumpmode?'%':'m';
   if(!jumpval) sprintf(buf,"%s- %c",  j,u);
   else         sprintf(buf,"%s%d- %c",j,jumpval,u);
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
   display->SetJump(buf);
 #else
   DisplayAtBottom(buf);
@@ -441,7 +452,7 @@ void cMPlayerControl::JumpProcess(eKeys Key)
   if(!jumpactive) {
     if(jumphide) Hide();
     else 
-#if VDRVERSNUM >= 10307
+#if APIVERSNUM >= 10307
       display->SetJump(0);
 #else
       DisplayAtBottom(0);
@@ -515,7 +526,7 @@ eOSState cMPlayerControl::ProcessKey(eKeys Key)
   //    case kYellow:  player->SkipNext(); break;
 
       case kBack:
-#if VDRVERSNUM >= 10332
+#if APIVERSNUM >= 10332
                      Hide();
                      cRemote::CallPlugin(i18n_name);
                      return osBack;
@@ -594,11 +605,11 @@ public:
   virtual eOSState ProcessKey(eKeys Key);
   };
 
+static const char *excl_sum[] = { ".*","*.summary","*.txt","*.nfo",0 };
+
 cMenuMPlayBrowse::cMenuMPlayBrowse(void)
-:cMenuBrowse(MPlaySources.GetSource(),false,false,tr("MPlayer browser"))
+:cMenuBrowse(MPlaySources.GetSource(),false,false,tr("MPlayer browser"),excl_sum)
 {
-  static const char *excl_br[] = { ".*","*.summary",0 };
-  excl=excl_br;
   sourcing=aidedit=false;
   SetButtons();
 }
@@ -607,7 +618,7 @@ void cMenuMPlayBrowse::SetButtons(void)
 {
   static char blue[12];
   snprintf(blue,sizeof(blue),MPlayerAid>=0 ? "AID:%d" : "AID:def",MPlayerAid);
-  SetHelp(tr("Play"), MPlayerSetup.ResumeMode ? tr("Rewind"):0, tr("Source"), blue);
+  SetHelp(tr(BUTTON"Play"), MPlayerSetup.ResumeMode ? tr(BUTTON"Rewind"):0, tr("Source"), blue);
   Display();
 }
 
@@ -633,12 +644,19 @@ eOSState cMenuMPlayBrowse::Summary(void)
 {
   cFileObj *item=CurrentItem();
   if(item && item->Type()==otFile) {
-    char *sum;
-    if(asprintf(&sum,"%s.summary",item->FullPath())>=0) {
-      int fd=open(sum,O_RDONLY);
-      free(sum);
+    static const char *exts[] = { ".summary",".txt",".nfo",0 };
+    for(int i=0; exts[i]; i++) {
+      char buff[4096];
+      strn0cpy(buff,item->FullPath(),sizeof(buff)-20);
+      char *e=&buff[strlen(buff)];
+      strn0cpy(e,exts[i],20);
+      int fd=open(buff,O_RDONLY);
+      *e=0;
+      if(fd<0 && (e=rindex(buff,'.'))) {
+        strn0cpy(e,exts[i],20);
+        fd=open(buff,O_RDONLY);
+        }
       if(fd>=0) {
-        char buff[4096];
         int r=read(fd,buff,sizeof(buff)-1);
         close(fd);
         if(r>0) {
@@ -702,6 +720,10 @@ static const char *DESCRIPTION    = "Media replay via MPlayer";
 static const char *MAINMENUENTRY  = "MPlayer";
 
 class cPluginMPlayer : public cPlugin {
+private:
+#if APIVERSNUM >= 10330
+  bool ExternalPlay(const char *path, bool test);
+#endif
 public:
   cPluginMPlayer(void);
   virtual ~cPluginMPlayer();
@@ -709,7 +731,7 @@ public:
   virtual const char *Description(void) { return tr(DESCRIPTION); }
   virtual const char *CommandLineHelp(void);
   virtual bool ProcessArgs(int argc, char *argv[]);
-#if VDRVERSNUM >= 10131
+#if APIVERSNUM >= 10131
   virtual bool Initialize(void);
 #else
   virtual bool Start(void);
@@ -718,6 +740,13 @@ public:
   virtual cOsdMenu *MainMenuAction(void);
   virtual cMenuSetupPage *SetupMenu(void);
   virtual bool SetupParse(const char *Name, const char *Value);
+#if APIVERSNUM >= 10330
+  virtual bool Service(const char *Id, void *Data);
+#if APIVERSNUM >= 10331
+  virtual const char **SVDRPHelpPages(void);
+  virtual cString SVDRPCommand(const char *Command, const char *Option, int &ReplyCode);
+#endif
+#endif
   };
 
 cPluginMPlayer::cPluginMPlayer(void)
@@ -741,9 +770,15 @@ const char *cPluginMPlayer::CommandLineHelp(void)
   asprintf(&help_str,"  -m CMD,   --mount=CMD    use CMD to mount/unmount/eject mp3 sources\n"
                      "                           (default: %s)\n"
                      "  -M CMD,   --mplayer=CMD  use CMD when calling MPlayer\n"
+                     "                           (default: %s)\n"
+                     "  -S SUB,   --sources=SUB  search sources config in SUB subdirectory\n"
+                     "                           (default: %s)\n"
+                     "  -R DIR,   --resume=DIR   store global resume file in DIR\n"
                      "                           (default: %s)\n",
                      mountscript,
-                     MPlayerCmd
+                     MPlayerCmd,
+                     sourcesSub ? sourcesSub:"none",
+                     globalResumeDir ? globalResumeDir:"video dir"
                      );
   return help_str;
 }
@@ -753,21 +788,25 @@ bool cPluginMPlayer::ProcessArgs(int argc, char *argv[])
   static struct option long_options[] = {
       { "mount",    required_argument, NULL, 'm' },
       { "mplayer",  required_argument, NULL, 'M' },
+      { "sources",  required_argument, NULL, 'S' },
+      { "resume",   required_argument, NULL, 'R' },
       { NULL }
     };
 
   int c, option_index = 0;
-  while((c=getopt_long(argc,argv,"m:M:",long_options,&option_index))!=-1) {
+  while((c=getopt_long(argc,argv,"m:M:S:R:",long_options,&option_index))!=-1) {
     switch (c) {
       case 'm': mountscript=optarg; break;
       case 'M': MPlayerCmd=optarg; break;
+      case 'S': sourcesSub=optarg; break;
+      case 'R': globalResumeDir=optarg; break;
       default:  return false;
       }
     }
   return true;
 }
 
-#if VDRVERSNUM >= 10131
+#if APIVERSNUM >= 10131
 bool cPluginMPlayer::Initialize(void)
 #else
 bool cPluginMPlayer::Start(void)
@@ -775,7 +814,7 @@ bool cPluginMPlayer::Start(void)
 {
   if(!CheckVDRVersion(1,1,16,"mplayer")) return false;
   i18n_name=Name();
-  MPlaySources.Load(AddDirectory(ConfigDirectory(),"mplayersources.conf"));
+  MPlaySources.Load(AddDirectory(ConfigDirectory(sourcesSub),"mplayersources.conf"));
   if(MPlaySources.Count()<1) {
     esyslog("ERROR: you must have defined at least one source in mplayersources.conf");
     fprintf(stderr,"No source(s) defined in mplayersources.conf\n");
@@ -813,4 +852,93 @@ bool cPluginMPlayer::SetupParse(const char *Name, const char *Value)
   return true;
 }
 
+#if APIVERSNUM >= 10330
+
+bool cPluginMPlayer::ExternalPlay(const char *path, bool test)
+{
+  char real[PATH_MAX+1];
+  if(realpath(path,real)) {
+    cFileSource *src=MPlaySources.FindSource(real);
+    if(src) {
+      cFileObj *item=new cFileObj(src,0,0,otFile);
+      if(item) {
+        item->SplitAndSet(real);
+        if(item->GuessType()) {
+          if(item->Exists()) {
+            if(!test) {
+              cMPlayerControl::SetFile(item,true);
+              cControl::Launch(new cMPlayerControl);
+              cControl::Attach();
+              }
+            delete item;
+            return true;
+            }
+          else dsyslog("MPlayer service: cannot play '%s'",path);
+          }
+        else dsyslog("MPlayer service: GuessType() failed for '%s'",path);
+        delete item;
+        }
+      }
+    else dsyslog("MPlayer service: cannot find source for '%s', real '%s'",path,real);
+    }
+  else if(errno!=ENOENT && errno!=ENOTDIR)
+    esyslog("ERROR: realpath: %s: %s",path,strerror(errno));
+  return false;
+}
+
+bool cPluginMPlayer::Service(const char *Id, void *Data)
+{
+  if(!strcasecmp(Id,"MPlayer-Play-v1")) {
+    if(Data) {
+      struct MPlayerServiceData *msd=(struct MPlayerServiceData *)Data;
+      msd->result=ExternalPlay(msd->data.filename,false);
+      }
+    return true;
+    }
+  else if(!strcasecmp(Id,"MPlayer-Test-v1")) {
+    if(Data) {
+      struct MPlayerServiceData *msd=(struct MPlayerServiceData *)Data;
+      msd->result=ExternalPlay(msd->data.filename,true);
+      }
+    return true;
+    }
+  return false;
+}
+
+#if APIVERSNUM >= 10331
+
+const char **cPluginMPlayer::SVDRPHelpPages(void)
+{
+  static const char *HelpPages[] = {
+    "PLAY <filename>\n"
+    "    Triggers playback of file 'filename'.",
+    "TEST <filename>\n"
+    "    Tests is playback of file 'filename' is possible.",
+    NULL
+    };
+  return HelpPages;
+}
+
+cString cPluginMPlayer::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode)
+{
+  if(!strcasecmp(Command,"PLAY")) {
+    if(*Option) {
+      if(ExternalPlay(Option,false)) return "Playback triggered";
+      else { ReplyCode=550; return "Playback failed"; }
+      }
+    else { ReplyCode=501; return "Missing filename"; }
+    }
+  else if(!strcasecmp(Command,"TEST")) {
+    if(*Option) {
+      if(ExternalPlay(Option,true)) return "Playback possible";
+      else { ReplyCode=550; return "Playback not possible"; }
+      }
+    else { ReplyCode=501; return "Missing filename"; }
+    }
+  return NULL;
+}
+
+#endif // 1.3.31
+#endif // 1.3.30
+
 VDRPLUGINCREATOR(cPluginMPlayer); // Don't touch this!
