@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2005 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2006 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1227,9 +1227,9 @@ cOutputDvb::cOutputDvb(cMP3Player *Player)
 {
   only48khz=MP3Setup.Only48kHz;
   outSr=0;
-#if VDRVERSNUM == 10318
+#if APIVERSNUM == 10318
   cDevice::PrimaryDevice()->SetCurrentAudioTrack(ttDolbyFirst);
-#elif VDRVERSNUM >= 10319
+#elif APIVERSNUM >= 10319
   cDevice::PrimaryDevice()->SetCurrentAudioTrack(ttAudio);
 #endif
   d(printf("mp3-dvb: using DVB output\n"))
@@ -1330,7 +1330,7 @@ int cOutputDvb::Output(const unsigned char *Data, int Len, bool SOF)
         int pc=sizeof(testAudio);
         int r;
         do {
-#if VDRVERSNUM < 10318
+#if APIVERSNUM < 10318
           r=player->PlayVideo(p,pc);
 #else
           r=player->PlayPes(p,pc);
@@ -1346,7 +1346,7 @@ int cOutputDvb::Output(const unsigned char *Data, int Len, bool SOF)
     n=FHS;
     Data+=n; Len-=n;
     }
-#if VDRVERSNUM < 10318
+#if APIVERSNUM < 10318
   int r=player->PlayVideo(Data,Len);
 #else
   int r=player->PlayPes(Data,Len);
@@ -1630,7 +1630,7 @@ next:
       imageCheck=time_ms()+250;
       imageValid=playing->Image(mem,len);
       if(mem) {
-        if(playindex) usleep(80*1000); // stillpicture ioctl freezes without this
+        if(playindex) SLEEP(80); // stillpicture ioctl freezes without this
         DeviceStillPicture(mem,len);
         free(mem);
         }
@@ -1839,7 +1839,7 @@ next:
     else if(playMode!=pmPlay) {
       mgr->Throttle(false);
       if(!imageValid)
-        usleep(100*1000);
+        SLEEP(100);
       else {
         playModeMutex.Lock();
         if(playMode!=pmPlay) WaitPlayMode(playMode,true);
