@@ -46,11 +46,10 @@
 //#define DEBUG_SLAVE
 
 #define MPLAYER_VOL_STEP 3.0
-#define VDR_2_MPLAYER(x) ((float)(x)/2.55)
-#define MPLAYER_2_VDR(x) (MIN((int)((x)*2.55),255))
 
 const char *MPlayerCmd = "mplayer.sh";
 int MPlayerAid=-1;
+const char *globalResumeDir = 0;
 
 // -- cMPlayerStatus -----------------------------------------------------------
 
@@ -66,7 +65,11 @@ bool cMPlayerStatus::GetVolume(int &Volume, bool &Mute)
 {
   Lock();
   bool r=changed;
-  Volume=volume; Mute=mute;
+  // convert according cDvbDevice::SetVolumeDevice();
+  // take into account that VDR does non-linear changes, while
+  // MPlayer does linear volume changes.
+  Volume=((2*volume-volume*volume/255)*100+128)/256;
+  Mute=mute;
   changed=false;
   Unlock();
   return r;
@@ -77,7 +80,15 @@ void cMPlayerStatus::SetVolume(int Volume, bool Absolute)
   Lock();
   if(Absolute && Volume==0) mute=true;
   else {
-    volume=Volume;
+#if APIVERSNUM>=10401
+#if APIVERSNUM==10401
+#warning Caution! This code does not work with VDR 1.4.1 and 1.4.1-1. You can ignore this warning if you are using VDR 1.4.1-2 or later.
+#endif
+    if(!Absolute)
+      volume+=Volume;
+    else
+#endif
+      volume=Volume;
     if(volume>0) mute=false;
     }
   d(printf("status: volume=%d mute=%d\n",volume,mute))
@@ -146,13 +157,13 @@ void cMPlayerResume::SetResume(const cFileObj *file, float pos)
   else if(pos>99.0) pos=99.0;
   cResumeEntry *re;
   if(OpenResume(file) && (re=FindResume(file))) {
-    d(printf("resume: setting resume %f (update)",pos))
+    d(printf("resume: setting resume %f (update)\n",pos))
     }
   else {
     re=new cResumeEntry;
     re->name=strdup(global ? file->FullPath() : file->Name());
     Add(re);
-    d(printf("resume: setting resume %f (new)",pos))
+    d(printf("resume: setting resume %f (new)\n",pos))
     }
   re->pos=pos;
   modified=true;
@@ -180,7 +191,7 @@ bool cMPlayerResume::OpenResume(const cFileObj *file)
     if(MPlayerSetup.ResumeMode==1 || 
        (access(s,W_OK) && (errno==EACCES || errno==EROFS))) {
       global=true;
-      resfile=AddPath(VideoDirectory,GLOBAL_RESUME_FILE);
+      resfile=AddPath(globalResumeDir?globalResumeDir:VideoDirectory,GLOBAL_RESUME_FILE);
       d(printf("resume: using global file\n"))
       }
     else {
@@ -313,24 +324,29 @@ void cMPlayerPlayer::Activate(bool On)
     }
   else if(started) {
     run=false;
-    if(slave) {
-      Play(); // MPlayer ignores "quit" while paused
-      MPlayerControl("quit");
-      int until=time_ms()+3000; // wait some time until MPlayer is gone
-      d(printf("mplayer: waiting for child exit"))
-      while(!waitpid(pid,0,WNOHANG)) {
-        if(time_ms()>until) {
-          kill(pid,SIGKILL); // kill it anyways
-          d(printf(" SIGKILL"))
-          break;
+    if(Active()) {
+      if(slave) {
+        Play(); // MPlayer ignores "quit" while paused
+        MPlayerControl("quit");
+        int until=time_ms()+3000; // wait some time until MPlayer is gone
+        d(printf("mplayer: waiting for child exit"))
+        while(Active()) {
+          if(time_ms()>until) {
+            kill(pid,SIGKILL); // kill it anyways
+            d(printf(" SIGKILL"))
+            break;
+            }
+          SLEEP(250);
+          d(printf(".")) d(fflush(stdout))
           }
-        usleep(250*1000);
-        d(printf("."))
+        d(printf("\n"))
         }
-      d(printf("\n"))
+      else {
+        kill(pid,SIGTERM);
+        d(printf("mplayer: waiting for child exit (non-slave)\n"))
+        }
+      waitpid(pid,0,0);
       }
-    else kill(pid,SIGTERM);
-    waitpid(pid,0,0); // get status otherwise the child stays as a zombie forever
     ClosePipe();
     Cancel(2);
     started=slave=false;
@@ -339,9 +355,7 @@ void cMPlayerPlayer::Activate(bool On)
 
 bool cMPlayerPlayer::Active(void)
 {
-  if(kill(pid,0)<0 && errno==ESRCH) return false;
-  waitpid(pid,0,WNOHANG);
-  return true;
+  return waitpid(pid,0,WNOHANG)==0;
 }
 
 bool cMPlayerPlayer::Fork(void)
@@ -387,7 +401,7 @@ bool cMPlayerPlayer::Fork(void)
     else aid[0]=0;
     snprintf(cmd,sizeof(cmd),"%s \"%s\" %s%s",MPlayerCmd,fname,MPlayerSetup.SlaveMode?"SLAVE":"",aid);
     free(fname);
-    execle("/bin/sh","sh","-c",cmd,0,environ);
+    execle("/bin/sh","sh","-c",cmd,(char *)0,environ);
     esyslog("ERROR: exec failed for %s: (%d) %s",cmd,errno,strerror(errno));
     exit(127);
     }
@@ -397,7 +411,7 @@ bool cMPlayerPlayer::Fork(void)
     close(outpipe[1]); pipefl&=~8;
     fcntl(outpipe[0],F_SETFL,O_NONBLOCK);
     run=slave=true;
-    mpVolume=VDR_2_MPLAYER(255);
+    mpVolume=100; // MPlayer startup defaults
     mpMute=false;
     Start();
     }
@@ -465,7 +479,9 @@ void cMPlayerPlayer::Action(void)
               nextTime=nextPos=0;
               d(printf("PLAYBACK STARTED\n"))
               if(resPos>=0.0) {
-                if(!currentName || !strcmp(currentName,file->Path()))
+                if(!currentName ||
+                   !strcmp(currentName,file->FullPath()) ||
+                   !strcmp(currentName,file->Path()))
                   MPlayerControl("seek %.1f 1",resPos);
                 else
                   d(printf("mplayer: no resume, seems to be playlist\n"))
@@ -480,6 +496,10 @@ void cMPlayerPlayer::Action(void)
             LOCK_THREAD;
             free(currentName);
             currentName=strdup(::index(buff,' ')+1);
+            if(currentName[0]) {
+              int l=strlen(currentName);
+              if(currentName[l-1]=='.') currentName[l-1]=0; // skip trailing dot
+              }
             d(printf("PLAYING %s\n",currentName))
             }
           else if(sscanf(buff,"ANS_LENGTH=%d",&itime)==1) {
@@ -523,8 +543,10 @@ void cMPlayerPlayer::Action(void)
           }
         } while(c>0 && p);
       }
-    SetMPlayerVolume(index>=0 && force);
-    force=false;
+    if(playBack) {
+      SetMPlayerVolume(force);
+      force=false;
+      }
     }
 
   if(resume && curPos>=0.0) resume->SetResume(file,curPos);
@@ -541,20 +563,17 @@ void cMPlayerPlayer::SetMPlayerVolume(bool force)
   bool mute;
   Lock();
   if(status->GetVolume(volume,mute) || force) {
-    const float mpNewVol=VDR_2_MPLAYER(volume);
     if(mute) {
       if(!mpMute) { MPlayerControl("mute"); mpMute=true; }
       }
     else {
       if(mpMute) { MPlayerControl("mute"); mpMute=false; }
-      const int dir=mpNewVol>=mpVolume ? 1 : -1;
-      while(fabs(mpNewVol-mpVolume)>=(MPLAYER_VOL_STEP/2)) {
-        MPlayerControl("volume %d",dir);
-        mpMute=false;
-        mpVolume+=MPLAYER_VOL_STEP * (float)dir;
+      if(volume!=mpVolume) {
+        MPlayerControl("volume %d 1",volume);
+        mpVolume=volume;
         }
       }
-    d(printf("mplayer: mpNewVol=%.2f mpVolume=%.2f mpMute=%d\n",mpNewVol,mpVolume,mpMute))
+    d(printf("mplayer: volume=%d mpVolume=%d mpMute=%d\n",volume,mpVolume,mpMute))
     }
   Unlock();
 }
